You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@tapestry.apache.org by hl...@apache.org on 2007/02/19 05:01:41 UTC

svn commit: r509083 - in /tapestry/tapestry5/tapestry-core/trunk/src/main/java/org/apache/tapestry/corelib/components: Grid.java GridColumns.java GridRows.java

Author: hlship
Date: Sun Feb 18 20:01:40 2007
New Revision: 509083

URL: http://svn.apache.org/viewvc?view=rev&rev=509083
Log:
Fix some parameters connecting the Grid component to its GridColumns and GridRows sub-components.

Modified:
    tapestry/tapestry5/tapestry-core/trunk/src/main/java/org/apache/tapestry/corelib/components/Grid.java
    tapestry/tapestry5/tapestry-core/trunk/src/main/java/org/apache/tapestry/corelib/components/GridColumns.java
    tapestry/tapestry5/tapestry-core/trunk/src/main/java/org/apache/tapestry/corelib/components/GridRows.java

Modified: tapestry/tapestry5/tapestry-core/trunk/src/main/java/org/apache/tapestry/corelib/components/Grid.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/tapestry-core/trunk/src/main/java/org/apache/tapestry/corelib/components/Grid.java?view=diff&rev=509083&r1=509082&r2=509083
==============================================================================
--- tapestry/tapestry5/tapestry-core/trunk/src/main/java/org/apache/tapestry/corelib/components/Grid.java (original)
+++ tapestry/tapestry5/tapestry-core/trunk/src/main/java/org/apache/tapestry/corelib/components/Grid.java Sun Feb 18 20:01:40 2007
@@ -129,8 +129,7 @@
 
     @SuppressWarnings("unused")
     @Component(parameters =
-    { "rowClass=rowClass", "provider=this", "rowsPerPage=rowsPerPage", "currentPage=currentPage",
-            "row=row" })
+    { "rowClass=rowClass", "rowsPerPage=rowsPerPage", "currentPage=currentPage", "row=row" })
     private GridRows _rows;
 
     @Component(parameters =

Modified: tapestry/tapestry5/tapestry-core/trunk/src/main/java/org/apache/tapestry/corelib/components/GridColumns.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/tapestry-core/trunk/src/main/java/org/apache/tapestry/corelib/components/GridColumns.java?view=diff&rev=509083&r1=509082&r2=509083
==============================================================================
--- tapestry/tapestry5/tapestry-core/trunk/src/main/java/org/apache/tapestry/corelib/components/GridRows.java (original)
+++ tapestry/tapestry5/tapestry-core/trunk/src/main/java/org/apache/tapestry/corelib/components/GridRows.java Sun Feb 18 20:01:40 2007
@@ -34,7 +34,7 @@
     private String _rowClass;
 
     /** Object that provides access to the bean and data models used to render the Grid. */
-    @Parameter(required = true)
+    @Parameter(value = "componentResources.container")
     private GridModelProvider _provider;
 
     /** Number of rows displayed on each page. Long result sets are split across multiple pages. */
--- tapestry/tapestry5/tapestry-core/trunk/src/main/java/org/apache/tapestry/corelib/components/GridColumns.java (original)
+++ tapestry/tapestry5/tapestry-core/trunk/src/main/java/org/apache/tapestry/corelib/components/GridColumns.java Sun Feb 18 20:01:40 2007
@@ -32,9 +32,10 @@
 public class GridColumns
 {
     /**
      * The object that provides access to bean and data models.
      */
-    @Parameter(required = true)
+    @Parameter(value = "componentResources.container")
     private GridModelProvider _dataProvider;
 
     private PropertyModel _columnModel;
@@ -32,9 +32,10 @@
 {
     /**
-     * The object that provides access to bean and data models.
+     * The object that provides access to bean and data models, which is typically the enclosing
+     * Grid component.
      */

Modified: tapestry/tapestry5/tapestry-core/trunk/src/main/java/org/apache/tapestry/corelib/components/GridRows.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/tapestry-core/trunk/src/main/java/org/apache/tapestry/corelib/components/GridRows.java?view=diff&rev=509083&r1=509082&r2=509083
==============================================================================